/// <reference types="node" />
/// <reference types="express" />
import * as Express from "express";
import * as net from "net";
export declare class WebServer {
    static server: net.Server;
    static app: Express.Application | any;
    private static port;
    private static router;
    private static staticRootPath;
    /**
     * 配置项目的根路径
     * @param rootPath 一般情况下它应该是__dirname，需在项目启动前配置
     * @deprecated 已过时
     */
    static setRootPath(rootPath: string): typeof WebServer;
    /**
     * 手动指定端口号
     * @param port 端口号
     */
    static setPort(port: number): typeof WebServer;
    /**
     * 挂载该Web服务器的router点
     * @param router
     */
    static setRouter(router: any): typeof WebServer;
    /**
     * 配置其它自定义中间件
     * @param {Express.RequestHandler | Express.ErrorRequestHandler | Express.NextFunction | any} handler
     */
    static useMiddleware(handler: Express.RequestHandler | Express.ErrorRequestHandler | Express.NextFunction | any): typeof WebServer;
    static listen(): Promise<typeof WebServer>;
    /**
     * 关闭该web服务器
     */
    static close(): void;
    private static bootstrap();
    /**
     * 配置项目根路径
     * @param {string} staticRootPath 一般为__dirname
     * @deprecated 已过时，2018-04-26 之后将移除
     */
    private static setStaticServerRootPath(staticRootPath);
    /**
     * @deprecated 过时的方法，不应由外部调用
     * 处理退出时的事件
     */
    private static setCloseHandle();
    /**
     * @deprecated 过时的方法，不应由外部调用
     */
    private static ready();
    /**
     * 异常事件注册
     */
    private static errorEventHandler();
    private static startup();
    /**
     * 从package.json当中读取cdn，并进行配置
     */
    private static setCDN();
    /**
     * 中间件配置
     * 注意：执行顺序对应用的影响
     */
    private static setMiddleware();
}
